==> pochy-0.1.7a-src.tar.gz: pochy-0.1.7a-src/MailEditView.h <==
// MailEditView.h : CMailEditView NX̐錾уC^[tFCX̒`܂B
//
/////////////////////////////////////////////////////////////////////////////

#if !defined(AFX_MailEditView_H__B0C245CC_42EA_11D5_B88C_00008659960F__INCLUDED_)
#define AFX_MailEditView_H__B0C245CC_42EA_11D5_B88C_00008659960F__INCLUDED_

#include "PochyDoc.h"

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000

class CMailEditView : public CRichEditView
{
protected: // VACY@\݂̂쐬܂B
	CMailEditView();
	DECLARE_DYNCREATE(CMailEditView)

// Agr[g
public:
	CPochyDoc* GetDocument();

// Iy[V
public:
	void GetText(CString &buf);
	void Font();

// I[o[Ch
	// ClassWizard ͉z֐̃I[o[Ch𐶐܂B
	//{{AFX_VIRTUAL(CMailEditView)
	public:
	virtual void OnDraw(CDC* pDC);  // ̃r[`悷ۂɃI[o[Ch܂B
	virtual BOOL PreCreateWindow(CREATESTRUCT& cs);
	virtual void OnInitialUpdate();
	protected:
	virtual BOOL OnPreparePrinting(CPrintInfo* pInfo);
	virtual void OnBeginPrinting(CDC* pDC, CPrintInfo* pInfo);
	virtual void OnEndPrinting(CDC* pDC, CPrintInfo* pInfo);
	//}}AFX_VIRTUAL

// Cve[V
public:
	CFont m_font;
	void SetFontEx(LOGFONT &lf);
	int GetPos();
	int m_font_size;
	virtual ~CMailEditView();
	void SetFontColorAndLink();
#ifdef _DEBUG
	virtual void AssertValid() const;
	virtual void Dump(CDumpContext& dc) const;
#endif
	long m_onlink;

protected:
	afx_msg void OnLink( NMHDR* in_pNotifyHeader, LRESULT* out_pResult );

// ꂽbZ[W }bv֐
	//{{AFX_MSG(CMailEditView)
	afx_msg void OnChar(UINT nChar, UINT nRepCnt, UINT nFlags);
	afx_msg void OnKeyDown(UINT nChar, UINT nRepCnt, UINT nFlags);
	afx_msg void OnEditPaste();
	afx_msg void OnRButtonDown(UINT nFlags, CPoint point);
	afx_msg void OnEditviewPaste();
	afx_msg void OnEditviewCopy();
	afx_msg void OnEditviewSelall();
	afx_msg void OnEditviewCut();
	afx_msg void OnEditviewUndo();
	afx_msg void OnEditviewPasteQuotation();
	afx_msg void OnDropFiles(HDROP hDropInfo);
	//}}AFX_MSG
	DECLARE_MESSAGE_MAP()
};

#ifndef _DEBUG  // MailEditView.cpp t@CfobO̎gp܂B
inline CPochyDoc* CMailEditView::GetDocument()
   { return (CPochyDoc*)m_pDocument; }
#endif

/////////////////////////////////////////////////////////////////////////////

//{{AFX_INSERT_LOCATION}}
// Microsoft Visual C++ ͑Os̒Oɒǉ̐錾}܂B

#endif // !defined(AFX_MailEditView_H__B0C245CC_42EA_11D5_B88C_00008659960F__INCLUDED_)

==> pochy-0.1.9-src.tar.gz: pochy-0.1.9-src/MailEditView.h <==
// MailEditView.h : CMailEditView NX̐錾уC^[tFCX̒`܂B
//
/////////////////////////////////////////////////////////////////////////////

#if !defined(AFX_MailEditView_H__B0C245CC_42EA_11D5_B88C_00008659960F__INCLUDED_)
#define AFX_MailEditView_H__B0C245CC_42EA_11D5_B88C_00008659960F__INCLUDED_

#include "PochyDoc.h"
#include "BitmapRichEditView.h"

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000

class CMailEditView : public CBitmapRichEditView
{
protected: // VACY@\݂̂쐬܂B
	CMailEditView();
	DECLARE_DYNCREATE(CMailEditView)

// Agr[g
public:
	CPochyDoc* GetDocument();

// Iy[V
public:
	void GetText(CString &buf);
	void Font();

// I[o[Ch
	// ClassWizard ͉z֐̃I[o[Ch𐶐܂B
	//{{AFX_VIRTUAL(CMailEditView)
	public:
	virtual void OnDraw(CDC* pDC);  // ̃r[`悷ۂɃI[o[Ch܂B
	virtual BOOL PreCreateWindow(CREATESTRUCT& cs);
	virtual void OnInitialUpdate();
	protected:
	virtual BOOL OnPreparePrinting(CPrintInfo* pInfo);
	virtual void OnBeginPrinting(CDC* pDC, CPrintInfo* pInfo);
	virtual void OnEndPrinting(CDC* pDC, CPrintInfo* pInfo);
	//}}AFX_VIRTUAL

// Cve[V
public:
	CFont m_font;
	void SetFontEx(LOGFONT &lf);
	int GetPos();
	int m_font_size;
	virtual ~CMailEditView();
	void SetFontColorAndLink();
#ifdef _DEBUG
	virtual void AssertValid() const;
	virtual void Dump(CDumpContext& dc) const;
#endif
	long m_onlink;

protected:
	afx_msg void OnLink( NMHDR* in_pNotifyHeader, LRESULT* out_pResult );

// ꂽbZ[W }bv֐
	//{{AFX_MSG(CMailEditView)
	afx_msg void OnChar(UINT nChar, UINT nRepCnt, UINT nFlags);
	afx_msg void OnKeyDown(UINT nChar, UINT nRepCnt, UINT nFlags);
	afx_msg void OnEditPaste();
	afx_msg void OnRButtonDown(UINT nFlags, CPoint point);
	afx_msg void OnEditviewPaste();
	afx_msg void OnEditviewCopy();
	afx_msg void OnEditviewSelall();
	afx_msg void OnEditviewCut();
	afx_msg void OnEditviewUndo();
	afx_msg void OnEditviewPasteQuotation();
	afx_msg void OnDropFiles(HDROP hDropInfo);
	//}}AFX_MSG
	DECLARE_MESSAGE_MAP()
};

#ifndef _DEBUG  // MailEditView.cpp t@CfobO̎gp܂B
inline CPochyDoc* CMailEditView::GetDocument()
   { return (CPochyDoc*)m_pDocument; }
#endif

/////////////////////////////////////////////////////////////////////////////

//{{AFX_INSERT_LOCATION}}
// Microsoft Visual C++ ͑Os̒Oɒǉ̐錾}܂B

#endif // !defined(AFX_MailEditView_H__B0C245CC_42EA_11D5_B88C_00008659960F__INCLUDED_)
